;;;; -*- Mode: Lisp; Package: cl-user -*-
;;;;
;;;; This is part of the acl-installer program: 
;;;;    http://kevin.rosenberg.net/acl-installer
;;;;
;;;; Copyright (c) 2002 Kevin M. Rosenberg
;;;;
;;;; acl-installer is free software; you can redistribute it and/or modify
;;;; it under the terms of the GNU General Public License (version 2) as
;;;; published by the Free Software Foundation.
;;;;
;;;; acl-install is distributed in the hope that it will be useful,
;;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;;; GNU General Public License for more details.
;;;;
;;;; You should have a copy of the GNU General Public License on your
;;;; Debian system in the file /usr/share/common-licenses/GPL-2


(in-package :cl-user)

(load "/usr/share/common-lisp/source/common-lisp-controller/common-lisp-controller.lisp")

(in-package :common-lisp-controller)

(defconstant +clc-impl+ "alisp")
(defconstant +lisp-dir-name+ "acl-pro")
(defconstant +clc-lib-dir+ "/usr/lib/common-lisp/alisp/" "Directory holding compiled files")

(defconstant +lpt-pathname+
  (make-pathname :name (format nil "logical-translations-~A" +clc-impl+)
		 :type "dat"
		 :directory (list :absolute "usr" "lib" +lisp-dir-name+)))

(init-common-lisp-controller +clc-lib-dir+ :version 3)

;; AllegroCL doesn't store logical patchnames in dumped images. So we need 
;;; routines to read and write all logical pathnames.
;;; The file "sys:siteinit.lisp" will call read-all-logical-pathnames to load in
;;; logical pathnames. Programs which dump lisp images should call the function
;;; c-l-c:write-all-logical-pathnames to store the current logical pathnames.

(defun write-logical-pathnames (hosts)
  (with-open-file (strm +lpt-pathname+
			:direction :output :if-exists :supersede)
		  (dolist (host hosts)
		    (format strm "~&~S \'(" host)
		    (dolist (trans (logical-pathname-translations host))
		      (format strm "(\"~A\" \"~A\") " (first trans) (second trans)))
		    (format strm ")~%"))))

(defun read-all-logical-pathnames ()
  (when (probe-file +lpt-pathname+)
    (with-open-file (strm +lpt-pathname+
			  :direction :input
			  :if-not-exists nil)
		    (unless strm (return-from read-all-logical-pathnames nil))
		    (do ((done nil)
			 (host (read strm nil 'eof) (read strm nil 'eof)))
			((eq host 'eof)
			 'done)
		      (setf (logical-pathname-translations host) (eval (read strm)))))))

(defun write-all-logical-pathnames ()
  #+allegro
  (let ((hosts '()))
    (maphash #'(lambda (k v) (push k hosts)) excl::*logical-pathname-translations*)
    (write-logical-pathnames hosts)))

;;; Override send-clc-command for implementation

(defun send-clc-command (command package)
  "Overrides global definition"
  (excl:run-shell-command (c-l-c:make-clc-send-command-string command package +clc-impl+)))

(export 'write-all-logical-pathnames)
(export 'write-logical-pathnames)
(export 'read-all-logical-pathnames)

(write-all-logical-pathnames)

